@@ -22,7 +22,7 @@ class MARCReader(Reader):
         from pymarc import MARCReader
 
         ## pass in a file object
-        reader = MARCReader(file('file.dat'))
+        reader = MARCReader(open('file.dat'))
         for record in reader:
             ...
 
